SystemOrganization addCategory: #ConfigurationOfTetris!

Object subclass: #ConfigurationOfTetris
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfTetris'!

!ConfigurationOfTetris commentStamp: 'StephaneDucasse 2/7/2015 19:04' prior: 0!
(ConfigurationOfTetris project version: '1.0') load

Tetris browse
	to browse the main class
	
Tetris new openInWorld	
	to play :)
	
Works at least in Pharo 40.!

!ConfigurationOfTetris class methodsFor: 'private' stamp: 'StephaneDucasse 2/7/2015 18:22'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfTetris class methodsFor: 'catalog' stamp: 'StephaneDucasse 2/7/2015 19:27'!
catalogChangeLog
		
 ^ '- Version 1. 0 7/02/2015 first full configuration 
[[[
(ConfigurationOfTetris project version: ''1.0'') load
]]]
'
	
	! !

!ConfigurationOfTetris class methodsFor: 'catalog' stamp: 'StephaneDucasse 2/7/2015 19:28'!
catalogDescription

^ 
'A simple Tetris implementation. The implementation could be improved. Do not hesitate to contact stephane.ducasse@inria.fr if you want.'! !

!ConfigurationOfTetris class methodsFor: 'catalog' stamp: 'StephaneDucasse 2/7/2015 19:29'!
catalogKeyClassesAndExample

	^ 'It is composed of three classes: ==Tetris==, ==TetrisBlock== and ==TetrisBoard==.

[[[ 
	Tetris new openInWorld.		
]]]	
'! !

!ConfigurationOfTetris class methodsFor: 'catalog' stamp: 'StephaneDucasse 2/7/2015 18:22'!
catalogKeywords
	^ #(Game Fun Tile Board)
	! !

!ConfigurationOfTetris class methodsFor: 'private' stamp: 'StephaneDucasse 2/7/2015 18:22'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfTetris class methodsFor: 'metacello support' stamp: 'StephaneDucasse 2/7/2015 18:22'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfTetris class methodsFor: 'metacello support' stamp: 'StephaneDucasse 2/7/2015 18:22'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfTetris class methodsFor: 'load' stamp: 'StephaneDucasse 2/7/2015 18:22'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfTetris class methodsFor: 'metacello support' stamp: 'StephaneDucasse 2/7/2015 18:22'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfTetris class methodsFor: 'accessing' stamp: 'StephaneDucasse 2/7/2015 18:22'!
project

	^self new project! !

!ConfigurationOfTetris class methodsFor: 'metacello support' stamp: 'StephaneDucasse 2/7/2015 18:22'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfTetris methodsFor: 'baselines' stamp: 'StephaneDucasse 2/8/2015 18:44'!
baseline10: spec
	<version: '1.0-baseline'>
	spec
		for: #pharo
		do: [ 
			spec blessing: #baseline.
			spec description: 'First Configuration'.
			spec author: 'StephaneDucasse'.
			spec timestamp: '07/02/2015'.
			spec repository: 'http://www.smalltalkhub.com/mc/StephaneDucasse/Tetris/main'.
			
			spec package: 'Tetris' with: [ spec requires: 'LED' ].
			
			spec
				project: 'LED'
				with: [ 
					spec
						className: 'ConfigurationOfLEDMorph';
						versionString: #stable;
						repository: 'http://smalltalkhub.com/mc/PharoExtras/LEDMorph/main' ].
			spec
				group: 'default' with: #('Tetris');
				group: 'Core' with: #('Tetris') ].
	! !

!ConfigurationOfTetris methodsFor: 'accessing' stamp: 'StephaneDucasse 2/7/2015 18:22'!
customProjectAttributes
	^#()
	! !

!ConfigurationOfTetris methodsFor: 'symbolic versions' stamp: 'StephaneDucasse 2/7/2015 18:22'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.0'.
! !

!ConfigurationOfTetris methodsFor: 'accessing' stamp: 'StephaneDucasse 2/7/2015 18:22'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfTetris methodsFor: 'symbolic versions' stamp: 'StephaneDucasse 2/7/2015 18:22'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #common version: '1.0'.
	! !

!ConfigurationOfTetris methodsFor: 'versions' stamp: 'StephaneDucasse 2/7/2015 19:04'!
version10: spec 
	<version: '1.0' imports: #('1.0-baseline' )>
	
	spec for: #common
		do: [ spec package: 'Tetris' with: 'Tetris-StephaneDucasse.7' ]
	! !
